##  Implemented Security Measures in SAP LeanIX
Here is a list of the major measures we have implemented: 256-bit SSL encryption, extended validation from well-known Verisign, an ISO27001 certified service provider, daily database back-up, database encryption of certain fields like e-mail address, and extended password hashing.
SAP LeanIX was furthermore certified by German TÜV in 2015, indicating that data privacy and IT security measures are states of the art, particularly according to ISO/IEC 27000. For any security-related concerns, feel free to reach out to [SAP LeanIX Support![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.leanix.net%2Fsupport "https://www.leanix.net/support"). If you're an SAP customer, submit a request from the [SAP for Me![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fme.sap.com%2F "https://me.sap.com/") portal.
YesNo
Send
